Input

Trait Input 

pub trait Input {
    // Required method
    fn read_byte(&mut self) -> Option<u8>;
}
Types that can be used as input for the CNF parser.

Required Methods

fn read_byte(&mut self) -> Option<u8>

Reads a byte from the input if any is remaining.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a> Input for &'a [u8]

Source

fn read_byte(&mut self) -> Option<u8>

Implementors

Source

impl<R> Input for IoReader<R>
where R: Read,

Available on crate feature std only.